==> gramps-2:5.2.4-1-any.pkg.tar.zst: usr/lib/python3.13/site-packages/gramps/gen/filters/rules/family/_searchchildname.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

# -------------------------------------------------------------------------
#
# Standard Python modules
#
# -------------------------------------------------------------------------
from ....const import GRAMPS_LOCALE as glocale

_ = glocale.translation.gettext

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from ..person import SearchName
from ._memberbase import child_base


# -------------------------------------------------------------------------
#
# HasNameOf
#
# -------------------------------------------------------------------------
class SearchChildName(SearchName):
    """Rule that checks for full or partial name matches"""

    name = _("Families with any child matching the <name>")
    description = _(
        "Matches families where any child has a specified " "(partial) name"
    )
    category = _("Child filters")
    base_class = SearchName
    apply = child_base

==> gramps-2:6.0.1-3-any.pkg.tar.zst: usr/lib/python3.13/site-packages/gramps/gen/filters/rules/family/_searchchildname.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

# -------------------------------------------------------------------------
#
# Standard Python modules
#
# -------------------------------------------------------------------------
from ....const import GRAMPS_LOCALE as glocale

_ = glocale.translation.gettext

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from ..person import SearchName


# -------------------------------------------------------------------------
#
# Typing modules
#
# -------------------------------------------------------------------------
from ....lib import Family
from ....db import Database


# -------------------------------------------------------------------------
#
# HasNameOf
#
# -------------------------------------------------------------------------
class SearchChildName(SearchName):
    """Rule that checks for full or partial name matches"""

    name = _("Families with any child matching the <name>")
    description = _(
        "Matches families where any child has a specified " "(partial) name"
    )
    category = _("Child filters")

    def apply_to_one(self, db: Database, family: Family) -> bool:  # type: ignore[override]
        for child_ref in family.child_ref_list:
            child = db.get_person_from_handle(child_ref.ref)
            if super().apply_to_one(db, child):
                return True
        return False
